import 'dart:io';
import 'package:path_provider/path_provider.dart';
import '../logger.dart';
import 'package:path/path.dart' as p;
import '../log_output.dart';

/// Default implementation of [LogOutput].
///
/// It sends everything to the system console.
class ConsoleOutput extends LogOutput {
  final String fileExtension = '_app_log.text';
  File? _file;

  ///格式 2022-03-29
  late final String saveDate = '${DateTime.now().year}'
      '-'
      '${DateTime.now().month}'
      '-'
      '${DateTime.now().day}';

  @override
  void output(OutputEvent event) {
    for (var msg in event.lines) {
      pattern.allMatches(msg).forEach((match) => print(match.group(0)));
      if (event.isSave) {
        saveMsg(event, msg);
      }
    }
  }

  Future<Directory?> getPlatformSavePath() async {
    return Platform.isAndroid
        ? await getExternalStorageDirectory()
        : Platform.isIOS
            ? await getApplicationSupportDirectory()
            : await getTemporaryDirectory();
  }

  void saveMsg(OutputEvent event, String msg) async {
    String filePath = event.savePath;
    if (filePath.isEmpty) {
      filePath = (await getPlatformSavePath())?.path ?? '';
    }
    if (filePath.isEmpty) {
      return;
    }
    _file ??= File(p.join(filePath + "/log", saveDate + fileExtension));
    msg = '${DateTime.now()}' + msg + '\n';
    if (!_file!.existsSync()) {
      _file!.createSync(recursive: true);
    }
    _file?.writeAsStringSync(msg, mode: FileMode.append, flush: true);
  }
}
